import { Chat } from "./chat.js";
import { User } from "./user.js";
/** Everything here is great to use with the WebSocket you can get with {@link API.generateWebSocket}! */
export declare namespace WebSocket {
    /**
     * Use any of those with `socket.send()` to send a command to the WebSocket!
     * @example `socket.send(osu.WebSocket.Command.chatStart)`
     */
    namespace Command {
        const chatStart: string;
        const chatEnd: string;
    }
    /** Those are what you'll get from WebSocket's `MessageEvent`s! */
    namespace Event {
        interface ChatChannelJoin {
            event: "chat.channel.join";
            data: Chat.Channel.WithDetails;
        }
        interface ChatChannelLeave {
            event: "chat.channel.part";
            data: Chat.Channel.WithDetails;
        }
        interface ChatMessageNew {
            event: "chat.message.new";
            data: {
                messages: Chat.Message[];
                users: User[];
            };
        }
        /** That's the type of `JSON.parse(m.toString())` where `m` is a WebSocket's `MessageEvent`! */
        type Any = ChatChannelJoin | ChatChannelLeave | ChatMessageNew;
    }
}
